; bore.cnc - Probe the center of a circular bore
;
;   Marc Leonard
;   CNC Services Northwest
;   www.cncsnw.com
;
; Call:
;   M98 "bore.cnc"
; or:
;   G65 "bore.cnc"
;
; Example:
;     M25                  ; move to Z home
;     G43 H#9012           ; length compensation for probe
;     G0 X0 Y0             ; move over bore (old X0Y0)
;     M125/Z-.5 F100 P-15  ; "safe" move down into bore
;     M98 "bore.cnc"       ; probe center of bore
;     G92 X0 Y0            ; reset X0Y0 to exact center
;     M25                  ; back to Z home
;

 #1 = #4003     ; save positioning mode (90/91)
 #2 = #4109     ; save feedrate
 #3 = #4001     ; save movement mode (0/1/2/3)

 M116/X F#9014 P-#9011     ; fast probe X+
 M115/X F#9014 P#9011      ; move clear
 G1 G91 F#9014 X-#9013
 M116/X F#9015 P-#9011     ; slow probe X+
 #10 = #5041               ; save coordinate of right wall
 M115/X F#9014 P#9011      ; move clear
 M115/X F#9014 P-#9011     ; fast probe X-
 M116/X F#9014 P#9011      ; move clear
 G1 G91 F#9014 X#9013
 M115/X F#9015 P-#9011     ; slow probe X-
 #10 = [#10+#5041]/2.0     ; calculate midpoint between walls
 M116/X F#9014 P#9011      ; move clear
 G1 G91 F#9014 X#9013
 G90 M126/X#10 F#9014 P-#9011  ; move X back to midpoint

 M116/Y F#9014 P-#9011     ; fast probe Y+
 M115/Y F#9014 P#9011      ; move clear
 G1 G91 F#9014 Y-#9013
 M116/Y F#9015 P-#9011     ; slow probe Y+
 #11 = #5042               ; save coordinate of back wall
 M115/Y F#9014 P#9011      ; move clear
 M115/Y F#9014 P-#9011     ; fast probe Y-
 M116/Y F#9014 P#9011      ; move clear
 G1 G91 F#9014 Y#9013
 M115/Y F#9015 P-#9011     ; slow probe Y-
 #11 = [#11+#5042]/2.0     ; calculate midpoint between walls
 M116/Y F#9014 P#9011      ; move clear
 G1 G91 F#9014 Y#9013
 G90 M126/Y#11 F#9014 P-#9011  ; move Y back to midpoint

 G#1 G#3 F#2      ; restore saved modals
M99
